@@ -1,8 +1,8 @@
 #-*- encoding=utf8 -*-
 from .richdb import rich
 from .vdict import vdict
-from .ztime import Time, Timeseries
+from .ztime import Time
 from .wull import wull
 from .mdict import mdict
 from .version import __version__
-__all__ = ('rich', 'vdict', 'Time', 'Timeseries', 'wull', 'mdict')
\ No newline at end of file
+__all__ = ('rich', 'vdict', 'Time', 'wull', 'mdict')
\ No newline at end of file
